<?php
/**
 * @package       WebTolk plugin info field
 * @version       1.0.0
 * @Author        Sergey Tolkachyov, https://web-tolk.ru
 * @copyright     Copyright (C) 2020 Sergey Tolkachyov
 * @license       GNU/GPL http://www.gnu.org/licenses/gpl-2.0.html
 * @since         1.0.0
 */

defined('_JEXEC') or die;

use Joomla\CMS\Date\Date;
use Joomla\CMS\Form\FormHelper;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\Language\Text;
use \Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

FormHelper::loadFieldClass('note');

class JFormFieldPkgjoomshoppingprodamuspaymentmethodkeyinfo extends JFormFieldNote
{

	protected $type = 'pkgjoomshoppingprodamuspaymentmethodkeyinfo';

	/**
	 * Method to get the field input markup for a spacer.
	 * The spacer does not have accept input.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   1.7.0
	 */
	protected function getInput()
	{

		$plugin = PluginHelper::getPlugin('system', 'wtlicensemanager');
		$params = json_decode($plugin->params);
		$html   = '<p>';
		$domain         = $params->pkg_joomshoppingprodamuspaymentmethod_domain;
		$current_uri    = Uri::getInstance();
		$current_domain = $current_uri->getHost();

		$timezone = Factory::getUser()->getTimezone();

		if (strpos($domain, $current_domain) === false && $domain)
		{
			$html .= '<span class="badge badge-important bg-danger">' . Text::_('PLG_WTLICENSEMANAGER_KEY_WRONG_DOMAIN_WARN') . '</span> ';
		}
		else
		{
			$html .= '<span class="badge badge-success bg-success">OK</span> ' . Text::_('PLG_WTLICENSEMANAGER_KEY_DOMAIN_OK');
		}

		if (!empty($params->pkg_joomshoppingprodamuspaymentmethod_date_start))
		{

			$html .= '<span class="badge badge-success bg-success">' . Text::_('PLG_WTLICENSEMANAGER_KEY_DATE_START') . '</span><span class="badge badge-info bg-info" id="pkg_joomshoppingprodamuspaymentmethod_date_start">' . $params->pkg_joomshoppingprodamuspaymentmethod_date_start . '</span> ';
		}

		if (!empty($params->pkg_joomshoppingprodamuspaymentmethod_date_end))
		{
			$date_end = new Date($params->pkg_joomshoppingprodamuspaymentmethod_date_end);
			$date_end->setTimezone($timezone);
			$date_end->format('d.m.Y');
			//echo $ostatok = new Date($date_end .' - 30days');
			$html .= '<span class="badge badge-success bg-success">' . Text::_('PLG_WTLICENSEMANAGER_KEY_DATE_END') . '</span><span class="badge badge-info bg-info" id="pkg_joomshoppingprodamuspaymentmethod_date_end">' . $date_end . '</span>';
		}

		$js = '
			jQuery(document).ready(function (){
				
                jQuery("#jform_params_pkg_joomshoppingprodamuspaymentmethod_key").keyup(function(){
            			let pkg_joomshoppingprodamuspaymentmethod_key = jQuery("#jform_params_pkg_joomshoppingprodamuspaymentmethod_key").val();
                        Joomla.request({
                            url: "https://web-tolk.ru/index.php?option=com_ajax&plugin=wt_get_sw_jprojects_key_info&group=system&format=json&element=pkg_joomshoppingprodamuspaymentmethod&download_key="+pkg_joomshoppingprodamuspaymentmethod_key,
                            onSuccess: function(response, xhr){
                                    let result = JSON.parse(response);
                                    let data = JSON.parse(result.data);

                                    if(data.domain){
                                        jQuery("[name = \"jform[params][pkg_joomshoppingprodamuspaymentmethod_domain]\"]").val(data.domain);
                                    }
                                    if(data.date_start){
                                        jQuery("[name = \"jform[params][pkg_joomshoppingprodamuspaymentmethod_date_start]\"]").val(data.date_start);
                                        jQuery("#pkg_joomshoppingprodamuspaymentmethod_date_start").html(data.date_start);
                                    }
                                    if(data.date_end){
                                        jQuery("[name = \"jform[params][pkg_joomshoppingprodamuspaymentmethod_date_end]\"]").val(data.date_end);
                                        jQuery("#pkg_joomshoppingprodamuspaymentmethod_date_end").html(data.date_end);
                                    }
                                    if(data.error){
                                        console.error("JoomShopping Prodamus, способ оплаты key info: " + data.error.code + " - " + data.error.description)
                                        Joomla.renderMessages({"error":["<span class=\"alert-link\">JoomShopping Prodamus, способ оплаты key info:</span> " + data.error.code + " - " + data.error.description]});
                                        jQuery("#pkg_joomshoppingprodamuspaymentmethod_date_end").html("");
                                        jQuery("#jform_params_pkg_joomshoppingprodamuspaymentmethod_date_end").val("");
                                        jQuery("#jform_params_pkg_joomshoppingprodamuspaymentmethod_date_start").val("");
                                        jQuery("#jform_params_pkg_joomshoppingprodamuspaymentmethod_domain").val("");
	                                    jQuery("#pkg_joomshoppingprodamuspaymentmethod_date_start").html("");
                                    } else {
                                        Joomla.renderMessages({"success":["<span class=\"alert-link\">JoomShopping Prodamus, способ оплаты key info:</span> ' . Text::_('PLG_WTLICENSEMANAGER_KEY_OK') . '"]});
                                    }
   
                                },
                            onError: function(xhr){
	                               console.log (xhr);
	                               Joomla.renderMessages({"warning":["<span class=\"alert-link\">JoomShopping Prodamus, способ оплаты key info:</span> ' . Text::_('PLG_WTLICENSEMANAGER_ERROR_FETCH_DATA_FROM_WEBTOLK') . '"]});
                                }
                        });
                        
                });
                
			});
			
			

		';
		Factory::getDocument()->addScriptDeclaration($js);

		return '</p>' . $html;
	}

	/**
	 * @return  string  The field label markup.
	 *
	 * @since   1.7.0
	 */
	protected function getLabel()
	{
		return Text::_('PLG_WTLICENSEMANAGER_KEY_INFO');
	}

	/**
	 * Method to get the field title.
	 *
	 * @return  string  The field title.
	 *
	 * @since   1.7.0
	 */
	protected function getTitle()
	{
		return $this->getLabel();
	}

}

?>